pub enum ProtocolReplayError {
Validation(String),
Conflict(String),
CursorExpired(String),
Integrity(String),
Io(String),
Serialization(String),
}Expand description
Errors returned by protocol replay log implementations.
Variants
Validation(String)
The provided input violates the replay-log contract.
Conflict(String)
The wire event already exists for the protocol stream with different data.
CursorExpired(String)
The requested cursor is outside retained replay history.
Integrity(String)
Replay history is missing a row that should still be retained.
Io(String)
An I/O error occurred.
Serialization(String)
A serialization or deserialization error occurred.