pub struct AgentEventNormalizationContext {
pub thread_id: String,
pub run_id: String,
pub origin: String,
pub correlation_id: Option<String>,
}Expand description
Scope and metadata used when normalizing runtime events that do not carry thread or run identifiers themselves.
Fields
thread_id: Stringrun_id: Stringorigin: Stringcorrelation_id: Option<String>Implementations
Sourceimpl AgentEventNormalizationContext
impl AgentEventNormalizationContext
Sourcepub fn new(
thread_id: impl Into<String>,
run_id: impl Into<String>,
origin: impl Into<String>,
) -> Result<AgentEventNormalizationContext, EventStoreError>
pub fn new( thread_id: impl Into<String>, run_id: impl Into<String>, origin: impl Into<String>, ) -> Result<AgentEventNormalizationContext, EventStoreError>
Create a normalization context for one thread/run pair.
Sourcepub fn with_correlation_id(
self,
correlation_id: impl Into<String>,
) -> AgentEventNormalizationContext
pub fn with_correlation_id( self, correlation_id: impl Into<String>, ) -> AgentEventNormalizationContext
Attach a correlation id used for tracing and diagnostics.