pub struct ThreadCommitStagedOutcome {
pub canonical_event_ids: Vec<String>,
pub server_event_ids: Vec<String>,
pub additional_outbox_ids: Vec<String>,
}Expand description
Identifiers assigned by stores during a successful staged commit.
Fields
canonical_event_ids: Vec<String>Canonical event ids in the same order as the input
canonical_drafts. Empty when the staged commit carried no events.
server_event_ids: Vec<String>Server-authored canonical event ids in the same order as the input
server_events. Empty when the staged commit attached no server events.
additional_outbox_ids: Vec<String>Outbox ids in the same order as additional_outbox. Empty when
the staged commit attached no inline-writer outbox rows.